@@ -15,21 +15,27 @@ use crate::transaction::TransactionController;
 
 #[async_trait]
 pub trait Context:
-    InvoiceCalculator
-    + ProductResolver
+    ClientContext
     + InventoryController
-    + ShippingCalculator
-    + PriceCalculator
     + TransactionController
     + CheckoutStore
-    + PaymentProcessor
     + PaymentStore
     + OrderStore
+{
+}
+
+#[async_trait]
+pub trait ClientContext:
+    InvoiceCalculator
+    + ProductResolver
+    + ShippingCalculator
+    + PriceCalculator
+    + PaymentProcessor
     + OrderEvents
 {
 }
 
 #[async_trait]
-pub trait ContextProvider<'a, T: Context> {
-    async fn new_context(&'a self) -> Result<T, Error>;
+pub trait ClientContextProvider<'a, C: ClientContext> {
+    async fn new_context(&'a self) -> Result<C, Error>;
 }
