@@ -8,12 +8,15 @@ pub struct InternalContext {
     pub pubsub_client: Arc<Client>,
     pub payment_processing_topic: Arc<Topic>,
     pub payment_processing_subscription: Arc<Subscription>,
+    pub order_events_topic: Arc<Topic>,
+    pub order_events_subscription: Arc<Subscription>,
 }
 
 impl InternalContext {
     pub async fn new(
         google_application_credentials: String,
         payment_processing_topic_name: String,
+        order_events_topic_name: String,
     ) -> Result<Self, Error> {
         let pubsub_client = Arc::new(
             cloud_pubsub::Client::new(google_application_credentials)
@@ -27,10 +30,16 @@ impl InternalContext {
         let payment_processing_subscription =
             Arc::new(pubsub_client.subscribe(payment_processing_topic_name));
 
+        let order_events_topic = Arc::new(pubsub_client.topic(order_events_topic_name.clone()));
+
+        let order_events_subscription = Arc::new(pubsub_client.subscribe(order_events_topic_name));
+
         Ok(Self {
             pubsub_client,
             payment_processing_topic,
             payment_processing_subscription,
+            order_events_topic,
+            order_events_subscription,
         })
     }
 }
