@@ -21,6 +21,22 @@ pub struct Tax {
     pub value: TaxValue,
 }
 
+impl Tax {
+    pub fn new_percentage(title: &str, value: &str) -> Self {
+        Self {
+            title: title.to_string(),
+            value: TaxValue::Percentage(Decimal::from_str(value).unwrap()),
+        }
+    }
+
+    pub fn new_absolute(title: &str, value: Money) -> Self {
+        Self {
+            title: title.to_string(),
+            value: TaxValue::Absolute(value),
+        }
+    }
+}
+
 #[derive(Clone, Serialize, Deserialize, JsonSchema)]
 pub struct LineItem {
     pub title: String,
