@@ -268,8 +268,7 @@ impl<'a, C: ClientContext + Send> PaymentStore for MasterContext<'a, C> {
     async fn create_payment(
         &mut self,
         payment: &Payment<
-            <Self as PaymentProcessor>::PrivateData,
-            <Self as PaymentProcessor>::PublicData,
+            <Self as PaymentProcessor>::Data,
             <Self as PaymentProcessor>::ProcessArgs,
         >,
     ) -> Result<(), Error> {
@@ -277,7 +276,7 @@ impl<'a, C: ClientContext + Send> PaymentStore for MasterContext<'a, C> {
 
         sqlx::query("INSERT INTO payments (id, correlation_id, data) VALUES ($1, $2, $3)")
             .bind(&payment.id)
-            .bind(&payment.data.correlation_id)
+            .bind(&payment.correlation_id)
             .bind(Json(payment))
             .execute(tx)
             .await
@@ -289,8 +288,7 @@ impl<'a, C: ClientContext + Send> PaymentStore for MasterContext<'a, C> {
     async fn update_payment(
         &mut self,
         payment: &Payment<
-            <Self as PaymentProcessor>::PrivateData,
-            <Self as PaymentProcessor>::PublicData,
+            <Self as PaymentProcessor>::Data,
             <Self as PaymentProcessor>::ProcessArgs,
         >,
     ) -> Result<(), Error> {
@@ -298,7 +296,7 @@ impl<'a, C: ClientContext + Send> PaymentStore for MasterContext<'a, C> {
 
         sqlx::query("UPDATE payments SET correlation_id = $2, data = $3 WHERE id = $1")
             .bind(&payment.id)
-            .bind(&payment.data.correlation_id)
+            .bind(&payment.correlation_id)
             .bind(Json(payment))
             .execute(tx)
             .await
@@ -387,29 +385,28 @@ impl<'a, C: ClientContext + Send> PaymentStore for MasterContext<'a, C> {
 // external implementation (PaymentProcessor)
 #[async_trait]
 impl<'a, C: ClientContext + Send> PaymentProcessor for MasterContext<'a, C> {
-    type PrivateData = <C as PaymentProcessor>::PrivateData;
-    type PublicData = <C as PaymentProcessor>::PublicData;
+    type Data = <C as PaymentProcessor>::Data;
     type ProcessArgs = <C as PaymentProcessor>::ProcessArgs;
 
     async fn initiate_payment(
         &mut self,
-        payment: &Payment<Self::PrivateData, Self::PublicData, Self::ProcessArgs>,
+        payment: &Payment<Self::Data, Self::ProcessArgs>,
         args: &Self::ProcessArgs,
-    ) -> Result<PaymentData<Self::PrivateData, Self::PublicData>, Error> {
+    ) -> Result<PaymentData<Self::Data>, Error> {
         self.client_ctx.initiate_payment(payment, args).await
     }
 
     async fn process_payment(
         &mut self,
-        payment: &Payment<Self::PrivateData, Self::PublicData, Self::ProcessArgs>,
+        payment: &Payment<Self::Data, Self::ProcessArgs>,
         args: &Self::ProcessArgs,
-    ) -> Result<ProcessingResult<Self::PrivateData, Self::PublicData>, Error> {
+    ) -> Result<ProcessingResult<Self::Data>, Error> {
         self.client_ctx.process_payment(payment, args).await
     }
 
     async fn cancel_payment(
         &mut self,
-        payment: &Payment<Self::PrivateData, Self::PublicData, Self::ProcessArgs>,
+        payment: &Payment<Self::Data, Self::ProcessArgs>,
     ) -> Result<CancellationResult, Error> {
         self.client_ctx.cancel_payment(payment).await
     }
@@ -421,11 +418,7 @@ impl<'a, C: ClientContext + Send> OrderEvents for MasterContext<'a, C> {
     async fn on_payment_in_progress(
         &mut self,
         order: &Order<
-            Payment<
-                <Self as PaymentProcessor>::PrivateData,
-                <Self as PaymentProcessor>::PublicData,
-                <Self as PaymentProcessor>::ProcessArgs,
-            >,
+            Payment<<Self as PaymentProcessor>::Data, <Self as PaymentProcessor>::ProcessArgs>,
         >,
     ) -> Result<(), Error> {
         self.client_ctx.on_payment_in_progress(order).await
@@ -434,11 +427,7 @@ impl<'a, C: ClientContext + Send> OrderEvents for MasterContext<'a, C> {
     async fn on_pending_confirmation(
         &mut self,
         order: &Order<
-            Payment<
-                <Self as PaymentProcessor>::PrivateData,
-                <Self as PaymentProcessor>::PublicData,
-                <Self as PaymentProcessor>::ProcessArgs,
-            >,
+            Payment<<Self as PaymentProcessor>::Data, <Self as PaymentProcessor>::ProcessArgs>,
         >,
     ) -> Result<(), Error> {
         self.client_ctx.on_pending_confirmation(order).await
@@ -447,11 +436,7 @@ impl<'a, C: ClientContext + Send> OrderEvents for MasterContext<'a, C> {
     async fn on_confirmed(
         &mut self,
         order: &Order<
-            Payment<
-                <Self as PaymentProcessor>::PrivateData,
-                <Self as PaymentProcessor>::PublicData,
-                <Self as PaymentProcessor>::ProcessArgs,
-            >,
+            Payment<<Self as PaymentProcessor>::Data, <Self as PaymentProcessor>::ProcessArgs>,
         >,
     ) -> Result<(), Error> {
         self.client_ctx.on_confirmed(order).await
@@ -460,11 +445,7 @@ impl<'a, C: ClientContext + Send> OrderEvents for MasterContext<'a, C> {
     async fn on_fulfilled(
         &mut self,
         order: &Order<
-            Payment<
-                <Self as PaymentProcessor>::PrivateData,
-                <Self as PaymentProcessor>::PublicData,
-                <Self as PaymentProcessor>::ProcessArgs,
-            >,
+            Payment<<Self as PaymentProcessor>::Data, <Self as PaymentProcessor>::ProcessArgs>,
         >,
     ) -> Result<(), Error> {
         self.client_ctx.on_fulfilled(order).await
@@ -473,11 +454,7 @@ impl<'a, C: ClientContext + Send> OrderEvents for MasterContext<'a, C> {
     async fn on_cancelled(
         &mut self,
         order: &Order<
-            Payment<
-                <Self as PaymentProcessor>::PrivateData,
-                <Self as PaymentProcessor>::PublicData,
-                <Self as PaymentProcessor>::ProcessArgs,
-            >,
+            Payment<<Self as PaymentProcessor>::Data, <Self as PaymentProcessor>::ProcessArgs>,
         >,
     ) -> Result<(), Error> {
         self.client_ctx.on_cancelled(order).await
