@@ -91,6 +91,28 @@ pub async fn confirm_handler<C: Context + Send>(
     Ok(od)
 }
 
+pub async fn complete_handler<C: Context + Send>(
+    internal_ctx: &InternalContext,
+    ctx: &mut C,
+    order_id: &str,
+) -> Result<
+    Order<Payment<<C as PaymentProcessor>::Data, <C as PaymentProcessor>::ProcessArgs>>,
+    Error,
+> {
+    let maybe_od = ctx.get_order_for_update(&order_id).await?;
+    if maybe_od.is_none() {
+        return Err(new_not_found_error(
+            "the requested order could not be found",
+        ));
+    }
+
+    let mut od = maybe_od.unwrap();
+    od.complete(internal_ctx, ctx).await?;
+    od.populate_associations(ctx).await?;
+
+    Ok(od)
+}
+
 pub async fn cancel_handler<C: Context + Send>(
     internal_ctx: &InternalContext,
     ctx: &mut C,
@@ -134,11 +156,11 @@ pub async fn cancel_handler<C: Context + Send>(
 
 pub async fn reconcile_handler<C: Context + Send>(
     ctx: &mut C,
-    lookup_key: LookupKey,
+    lookup_key: &LookupKey,
 ) -> Result<(), Error> {
     let maybe_order: Option<
         Order<Payment<<C as PaymentProcessor>::Data, <C as PaymentProcessor>::ProcessArgs>>,
-    > = match &lookup_key {
+    > = match lookup_key {
         LookupKey::CheckoutId(checkout_id) => get_order_by_checkout_id(ctx, checkout_id).await?,
         LookupKey::OrderId(order_id) => ctx.get_order_for_update(order_id).await?,
     };
