@@ -44,7 +44,7 @@ pub enum OrderState {
     Cancelled, // a terminal state
 }
 
-#[derive(Serialize, Deserialize)]
+#[derive(Debug, Serialize, Deserialize, JsonSchema)]
 pub enum LookupKey {
     CheckoutId(String),
     OrderId(String),
@@ -323,7 +323,7 @@ impl<P: Sync + Send + Serialize + DeserializeOwned> Order<P> {
         ctx.update_order(self).await
     }
 
-    pub async fn fulfill<C: Context + Send>(
+    pub async fn complete<C: Context + Send>(
         &mut self,
         internal_ctx: &InternalContext,
         ctx: &mut C,
