@@ -11,6 +11,21 @@ use super::{
     cancel, new, process, queue_for_processing, Initiator, InitiatorId, Payment, PaymentProcessor,
 };
 
+pub async fn get_handler<C: Context + Send>(
+    ctx: &mut C,
+    id: &str,
+) -> Result<Payment<<C as PaymentProcessor>::Data, <C as PaymentProcessor>::ProcessArgs>, Error> {
+    let maybe_payment = ctx.get_payment(id).await?;
+
+    if maybe_payment.is_none() {
+        return Err(new_not_found_error(
+            "the requested payment could not be found",
+        ));
+    }
+
+    Ok(maybe_payment.unwrap())
+}
+
 pub async fn create_handler<
     'a,
     C: Context + Send,
@@ -20,14 +35,7 @@ pub async fn create_handler<
     initiator: Initiator<'a, P>,
     charge_amount: Money,
     args: <C as PaymentProcessor>::ProcessArgs,
-) -> Result<
-    Payment<
-        <C as PaymentProcessor>::PrivateData,
-        <C as PaymentProcessor>::PublicData,
-        <C as PaymentProcessor>::ProcessArgs,
-    >,
-    Error,
-> {
+) -> Result<Payment<<C as PaymentProcessor>::Data, <C as PaymentProcessor>::ProcessArgs>, Error> {
     new(ctx, initiator, charge_amount, args).await
 }
 
@@ -36,14 +44,7 @@ pub async fn step_handler<C: Context + Send>(
     ctx: &mut C,
     id: &str,
     args: <C as PaymentProcessor>::ProcessArgs,
-) -> Result<
-    Payment<
-        <C as PaymentProcessor>::PrivateData,
-        <C as PaymentProcessor>::PublicData,
-        <C as PaymentProcessor>::ProcessArgs,
-    >,
-    Error,
-> {
+) -> Result<Payment<<C as PaymentProcessor>::Data, <C as PaymentProcessor>::ProcessArgs>, Error> {
     let maybe_payment = ctx.get_payment_for_update(id).await?;
     if maybe_payment.is_none() {
         return Err(new_not_found_error("the payment could not be found"));
@@ -60,14 +61,7 @@ pub async fn callback_handler<C: Context + Send>(
     ctx: &mut C,
     correlation_id: &str,
     args: <C as PaymentProcessor>::ProcessArgs,
-) -> Result<
-    Payment<
-        <C as PaymentProcessor>::PrivateData,
-        <C as PaymentProcessor>::PublicData,
-        <C as PaymentProcessor>::ProcessArgs,
-    >,
-    Error,
-> {
+) -> Result<Payment<<C as PaymentProcessor>::Data, <C as PaymentProcessor>::ProcessArgs>, Error> {
     let maybe_payment = ctx
         .get_payment_for_update_by_correlation_id(correlation_id)
         .await?;
@@ -87,11 +81,7 @@ pub async fn process_handler<C: Context + Send>(
     id: &str,
 ) -> Result<(), Error> {
     let maybe_payment: Option<
-        Payment<
-            <C as PaymentProcessor>::PrivateData,
-            <C as PaymentProcessor>::PublicData,
-            <C as PaymentProcessor>::ProcessArgs,
-        >,
+        Payment<<C as PaymentProcessor>::Data, <C as PaymentProcessor>::ProcessArgs>,
     > = ctx.get_payment_for_update(id).await?;
     if maybe_payment.is_none() {
         // this isn't supposed to happen.
@@ -106,11 +96,7 @@ pub async fn process_handler<C: Context + Send>(
         InitiatorId::Checkout(co_id) => {
             let maybe_co: Option<
                 Checkout<
-                    Payment<
-                        <C as PaymentProcessor>::PrivateData,
-                        <C as PaymentProcessor>::PublicData,
-                        <C as PaymentProcessor>::ProcessArgs,
-                    >,
+                    Payment<<C as PaymentProcessor>::Data, <C as PaymentProcessor>::ProcessArgs>,
                 >,
             > = ctx.get_checkout_for_update(co_id).await?;
             if maybe_co.is_none() {
@@ -144,11 +130,7 @@ pub async fn process_handler<C: Context + Send>(
                 ctx,
                 &mut payment,
                 Initiator::<
-                    Payment<
-                        <C as PaymentProcessor>::PrivateData,
-                        <C as PaymentProcessor>::PublicData,
-                        <C as PaymentProcessor>::ProcessArgs,
-                    >,
+                    Payment<<C as PaymentProcessor>::Data, <C as PaymentProcessor>::ProcessArgs>,
                 >::Order(&mut order),
             )
             .await
@@ -160,20 +142,9 @@ pub async fn cancel_handler<C: Context + Send>(
     internal_ctx: &InternalContext,
     ctx: &mut C,
     id: &str,
-) -> Result<
-    Payment<
-        <C as PaymentProcessor>::PrivateData,
-        <C as PaymentProcessor>::PublicData,
-        <C as PaymentProcessor>::ProcessArgs,
-    >,
-    Error,
-> {
+) -> Result<Payment<<C as PaymentProcessor>::Data, <C as PaymentProcessor>::ProcessArgs>, Error> {
     let maybe_payment: Option<
-        Payment<
-            <C as PaymentProcessor>::PrivateData,
-            <C as PaymentProcessor>::PublicData,
-            <C as PaymentProcessor>::ProcessArgs,
-        >,
+        Payment<<C as PaymentProcessor>::Data, <C as PaymentProcessor>::ProcessArgs>,
     > = ctx.get_payment_for_update(id).await?;
     if maybe_payment.is_none() {
         return Err(new_not_found_error("the payment could not be found"));
@@ -184,11 +155,7 @@ pub async fn cancel_handler<C: Context + Send>(
         InitiatorId::Checkout(co_id) => {
             let maybe_co: Option<
                 Checkout<
-                    Payment<
-                        <C as PaymentProcessor>::PrivateData,
-                        <C as PaymentProcessor>::PublicData,
-                        <C as PaymentProcessor>::ProcessArgs,
-                    >,
+                    Payment<<C as PaymentProcessor>::Data, <C as PaymentProcessor>::ProcessArgs>,
                 >,
             > = ctx.get_checkout_for_update(co_id).await?;
             if maybe_co.is_none() {
@@ -201,11 +168,7 @@ pub async fn cancel_handler<C: Context + Send>(
                 ctx,
                 &mut payment,
                 Initiator::<
-                    Payment<
-                        <C as PaymentProcessor>::PrivateData,
-                        <C as PaymentProcessor>::PublicData,
-                        <C as PaymentProcessor>::ProcessArgs,
-                    >,
+                    Payment<<C as PaymentProcessor>::Data, <C as PaymentProcessor>::ProcessArgs>,
                 >::Checkout(&mut checkout),
             )
             .await?;
@@ -222,11 +185,7 @@ pub async fn cancel_handler<C: Context + Send>(
                 ctx,
                 &mut payment,
                 Initiator::<
-                    Payment<
-                        <C as PaymentProcessor>::PrivateData,
-                        <C as PaymentProcessor>::PublicData,
-                        <C as PaymentProcessor>::ProcessArgs,
-                    >,
+                    Payment<<C as PaymentProcessor>::Data, <C as PaymentProcessor>::ProcessArgs>,
                 >::Order(&mut order),
             )
             .await?;
