@@ -64,7 +64,7 @@ pub trait PaymentProcessor {
         args: &Self::ProcessArgs,
     ) -> Result<ProcessingResult<Self::Data>, Error>;
 
-    // this is called synchronously and only once per revert request
+    // this is called synchronously and only once per release request
     async fn cancel_payment(
         &mut self,
         payment: &Payment<Self::Data, Self::ProcessArgs>,
@@ -226,7 +226,7 @@ pub async fn process<'a, C: Context + Send, P: Sync + Send + Serialize + Deseria
                     Initiator::Order(od) => od.prompt_confirmation(internal_ctx, ctx).await,
                 },
                 PaymentState::Cancelled => match initiator {
-                    Initiator::Checkout(co) => co.revert(ctx).await,
+                    Initiator::Checkout(co) => co.release(ctx).await,
                     Initiator::Order(od) => od.cancel(internal_ctx, ctx).await,
                 },
                 _ => Ok(()),
@@ -257,7 +257,7 @@ pub async fn cancel<'a, C: Context + Send, P: Sync + Send + Serialize + Deserial
             ctx.update_payment(payment).await?;
 
             match initiator {
-                Initiator::Checkout(co) => co.revert(ctx).await,
+                Initiator::Checkout(co) => co.release(ctx).await,
                 Initiator::Order(od) => od.cancel(internal_ctx, ctx).await,
             }
         }
